@@ -16,7 +16,7 @@ from termcolor import colored, cprint
 from .utils import net
 from loguru import logger
 from tenacity import retry, wait_fixed
-from .lib.process import process_data
+from .lib.process import process_data, KillError
 from .utils.runtime import load_runtime, write_runtime
 from .utils.process import Process, is_alive, ErrorCollector
 from .utils.kafka import KafkaMonitor, KafkaSender
@@ -36,7 +36,6 @@ DEFAULT_CONFIG = {
         "description": "test"
     },
     "controller_url": "http://127.0.0.1:5917",
-    "host": "127.0.0.1",  # 自身IP，用于控制器健康检查
     "log_level": "DEBUG",
     "log_file_path": os.getcwd()
 }
@@ -44,7 +43,7 @@ DEFAULT_CONFIG = {
 
 def initialize_logger(log_file_path=os.getcwd(), log_file_name=None, file_log_level="INFO", stderr_log_level="DEBUG"):
     """
-    Get logging handler
+    初始化日志模块
 
     :param log_file_path: the path of logging file
     :param log_file_name: the filename of logging file
@@ -61,7 +60,7 @@ def initialize_logger(log_file_path=os.getcwd(), log_file_name=None, file_log_le
 
 
 class Executor(object):
-    """Executor class."""
+    """核心类"""
     DEFAULT_POOL_SIZE = {"loop": 1, "async": 100, "thread": 100, "process": 10}
     RETRY_INTERVAL = 3
 
@@ -89,6 +88,9 @@ class Executor(object):
         self.kafka_arrangement = {}
 
     def init_runtimedump(self):
+        """
+        Runtime为运行是状态，该函数初始化运行状态信息并写文件(app.dump)
+        """
         self.runtime = load_runtime()
         if not self.runtime:
             self.runtime = {
@@ -104,12 +106,19 @@ class Executor(object):
             write_runtime(self.runtime)
 
     def reload_config(self):
+        """
+        加载配置文件，读取配置信息
+        """
         try:
             with open(self.config_file, "r") as f:
                 self.config = yaml.safe_load(f.read())
-            assert {"host", "type", "tags", "controller_url"} <= set(self.config.keys())
+            assert {"type", "tags", "controller_url"} <= set(self.config.keys())
             if "log_level" not in self.config.keys():
                 self.config["log_level"] = "INFO"
+            if "name" in self.config.keys():
+                self.name = self.config["name"]
+            if "log_file_path" not in self.config.keys():
+                self.config["log_file_path"] = os.getcwd()
 
         except FileNotFoundError:
             logger.error("Config File Is Not Found")
@@ -219,6 +228,9 @@ class Executor(object):
         return wrapper
 
     def update_config(self):
+        """
+        通过API更新配置，暂时弃用
+        """
         try:
             reboot = request.json["reboot"]
             config = request.json["config"]
@@ -235,7 +247,6 @@ class Executor(object):
     def register(self):
         """
         Register request
-        :param port: api port
         """
         try:
             data = {
@@ -266,11 +277,7 @@ class Executor(object):
     @retry(wait=wait_fixed(3))
     def receive_report(self, task_id, branch_id, position, input_length, partition, offset):
         """
-        First report
-        :param message: Structured kafka_message
-        :param partition: message partition
-        :param offset: message offset
-        :return: whether to do this task of not
+        收到任务后发送请求
         """
         try:
             data = {
@@ -296,6 +303,9 @@ class Executor(object):
 
     @retry(wait=wait_fixed(3))
     def finish_report(self, task, output_length, events, has_output, errors):
+        """
+        任务完成后发送请求，获得下一步kafka的方向
+        """
         try:
             data = {
                 "type": "finished",
@@ -318,21 +328,24 @@ class Executor(object):
             raise
 
     @retry(wait=wait_fixed(3))
-    def end_report(self, task, has_output, id, result, errors):
+    def end_report(self, task, has_output, branches, result, topic_partitions, errors):
+        """
+        任务结束后请求
+        """
         try:
             data = {
                 "type": "end",
                 "task_id": task.task_id,
                 "branch_id": task.branch_id,
-                "branch_amount": id,
+                "branch_amount": branches,
                 "current_position": task.position,
                 "has_output": has_output,
+                "topic_partitions": topic_partitions,
                 "result": result,
                 "errors": errors
             }
             re = requests.put(self.config["controller_url"] + "/task", json=data, headers={"Cookie": self.cookie})
             response = re.json()
-            print(response)
             if response["state"] is False:
                 raise ValueError("Error in controller response: %s" % re.text)
             if "segment" in response.keys() and response["segment"] is not None:
@@ -404,12 +417,16 @@ class Executor(object):
                 has_output = False
 
         outputs = self.finish_report(task, len(processed), self.events, has_output, error_collector.export())
+        if outputs == "kill":
+            raise KillError("Killed")
 
         # check externals
         # [FIX ME]
 
         # do output
+        branches = {}
         id = 0
+        topic_partitions= {}
         if has_output:
             task.properties["builtin"]["depth"] += 1
             sender = KafkaSender(self.kafka_url)
@@ -426,6 +443,11 @@ class Executor(object):
                     errors = []
                 if len(afterprocessed) == 0:
                     continue
+                else:
+                    if output["topic"] not in topic_partitions:
+                        topic_partitions[output["topic"]] = []
+                    topic_partitions[output["topic"]].append(output["partition"])
+
                 output_data = task_divide(afterprocessed, output["granularity"])
                 for data in output_data:
                     new_message = {
@@ -441,6 +463,9 @@ class Executor(object):
                         "body": data
                     }
                     sender.add_message(output["topic"], new_message, partition=output["partition"])
+                    if output["position"] not in branches:
+                        branches[output["position"]] = 0
+                    branches[output["position"]] += 1
                     id += 1
             result, info = sender.send_all()
             if not result:
@@ -448,9 +473,8 @@ class Executor(object):
                 error_collector.add("afterprocess", info)
         else:
             result = True
-            info = ""
 
-        self.end_report(task, has_output, id, result, error_collector.export())
+        self.end_report(task, has_output, branches, result, topic_partitions, error_collector.export())
 
     # ---------------------------  Process ------------------------------------------------
     def inside_kafka_process(self):
@@ -489,9 +513,10 @@ class Executor(object):
         self.running = False
 
 
-    # --------------------------  Trigger  --------------------------------------
+    # --------------------------  Trigger  已弃用 --------------------------------------
     def add_trigger(self, trigger):
         """
+
         Add a trigger to executor's triggers
         :param trigger: (Trigger) The trigger to add
         """
@@ -617,11 +642,11 @@ class Executor(object):
                 assert resp.status_code // 100 == 2
                 
                 data = resp.json()
-                print(data)
                 if data["segment"] != assignment:
-                    print(assignment)
                     assignment  = data["segment"]
                     queue.put_nowait(data["segment"])
+                    if data["segment"] == "kill":
+                        break
             except AssertionError:
                 logger.error("Error in health check, code: %d, Info: %s" % (resp.status_code, resp.text))
             except Exception as err:
@@ -653,11 +678,11 @@ class Executor(object):
         cprint(pyfiglet.figlet_format('Autumn', font='graffiti'),
                'green', attrs=['blink', 'bold'])
 
-        port = int(self.config["port"]) if "port" in self.config.keys() else net.get_free_port()
 
         # ---------- Register -----------
 
         self.queue = Queue(10)
+
         self.register()
         self.runtime["name"] = self.name
 
