@@ -10,10 +10,15 @@ import concurrent.futures
 class TimeoutError(Exception):
     pass
 
+class KafkaError(Exception):
+    pass
 
 class EnptyInputError(Exception):
     pass
 
+class KillError(Exception):
+    pass
+
 
 class EmptyOutputError(Exception):
     pass
