@@ -1,5 +1,6 @@
 from confluent_kafka import Producer, Consumer, TopicPartition, KafkaError
 from loguru import logger
+from  ..lib.process import KillError
 import time
 import json
 import random
@@ -16,8 +17,7 @@ def check_builtin_condition(key, now, end):
         else:
             return True
 
-class KafkaError(Exception):
-    pass
+
 
 
 class KafkaSender:
@@ -82,11 +82,11 @@ class KafkaConsumer(Consumer):
         """
         super().__init__({
             'bootstrap.servers': servers,
-            'group.id': 'autumn',
+            'group.id': 'autumn' + str(random.randint(0,9999999999)),
             'auto.offset.reset': 'earliest',
-            'enable.auto.commit': False
+            'enable.auto.commit': False,
+            'max.poll.interval.ms': 86400000
         })
-        self.subscribe(topics)
 
     def __del__(self):
         self.close()
@@ -130,6 +130,7 @@ class KafkaConsumer(Consumer):
                     time.sleep(1)
                     continue
                 raise KafkaError(message.error())
+            self.commit(message=message)
             return message
 
 
@@ -159,11 +160,11 @@ class KafkaMonitor(KafkaConsumer):
             while True:
                 try:
                     temp = self.executor.queue.get_nowait()
-                    print("tempppppp", temp)
                 except:
                     break
             if temp:
-                print(temp)
+                if temp == "kill":
+                    raise KillError("Killed")
                 self.executor.kafka_arrangement = temp
                 if self.executor.kafka_arrangement["partition"] != "":
                     self.assign([TopicPartition(self.topic, self.executor.kafka_arrangement["partition"], self.executor.kafka_arrangement["offset_range"][0])])
@@ -178,5 +179,4 @@ class KafkaMonitor(KafkaConsumer):
                 continue
             self.executor.kafka_arrangement["offset_range"][0] += 1
 
-            logger.debug(self.assignment())
             return super().poll()
